@@ -2,6 +2,12 @@ import pyautogui
 import os
 from time import sleep
 
+def found():
+	pass
+
+def notFound():
+	pass
+
 def find():
 	while True:
 		cwd = os.getcwd()
@@ -10,8 +16,10 @@ def find():
 				if file.endswith(".PNG" or ".png"):
 					image = file
 		if pyautogui.locateOnScreen(image) != None:
+			found()
 			print ("True")
 			sleep(0.5)
 		else:
+			notFound()
 			print ("False")
 			sleep(0.5)
\ No newline at end of file
